/*
 * Copyright (c) 2014 jstanice.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    jstanice - initial API and implementation and/or initial documentation
 */

package com.tasktop.c2c.server.profile.domain.project;

import com.tasktop.c2c.server.common.service.domain.AbstractEntity;

/**
 *
 * @author jstanice
 */
public class OrganizationProfile extends AbstractEntity implements Comparable<OrganizationProfile> {
    
    private Profile profile;
    private Boolean owner;
    private Boolean user;
    private Organization organization;
    
    public OrganizationProfile() {
        
    }

    public OrganizationProfile(Profile profile, Boolean owner, Boolean user, Organization organization) {
        this.profile = profile;
        this.owner = owner;
        this.user = user;
        this.organization = organization;
    }

    public Profile getProfile() {
        return profile;
    }

    public void setProfile(Profile profile) {
        this.profile = profile;
    }

    public Boolean isOwner() {
        return owner;
    }

    public void setOwner(Boolean owner) {
        this.owner = owner;
    }

    public Boolean isUser() {
        return user;
    }

    public void setUser(Boolean user) {
        this.user = user;
    }

    public Organization getOrganization() {
        return organization;
    }

    public void setOrganization(Organization organization) {
        this.organization = organization;
    }

    @Override
    public String toString() {
        return "OrganizationProfile{organization={" + organization != null ? organization.getName() : null
                + "}, profile={" + profile != null ? profile.getUsername() : null 
                + "}, owner=" + owner + ", user=" + user + "}";
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 79 * hash + (this.profile != null ? this.profile.hashCode() : 0);
        hash = 79 * hash + (this.organization != null ? this.organization.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final OrganizationProfile other = (OrganizationProfile) obj;
        if (this.profile != other.profile && (this.profile == null || !this.profile.equals(other.profile))) {
            return false;
        }
        if (this.organization != other.organization && (this.organization == null || !this.organization.equals(other.organization))) {
            return false;
        }
        return true;
    }

    public int compareTo(OrganizationProfile o) {
        int result = this.organization.compareTo(o.organization);
        if (result != 0) {
            return result;
        }
        return this.profile.compareTo(o.profile);
    }
    
}
